@@ -1,6 +1,7 @@
 from tabpy.tabpy_server.app.SettingsParameters import SettingsParameters
 from tabpy.tabpy_server.handlers import ManagementHandler
 import os
+from tabpy.tabpy_server.handlers.util import AuthErrorStates
 
 
 _QUERY_OBJECT_STAGING_FOLDER = "staging"
@@ -11,8 +12,8 @@ class UploadDestinationHandler(ManagementHandler):
         super(UploadDestinationHandler, self).initialize(app)
 
     def get(self):
-        if self.should_fail_with_not_authorized():
-            self.fail_with_not_authorized()
+        if self.should_fail_with_auth_error() != AuthErrorStates.NONE:
+            self.fail_with_auth_error()
             return
 
         path = self.settings[SettingsParameters.StateFilePath]
